/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __META_DBUS_LOGIN1_H__
#define __META_DBUS_LOGIN1_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.freedesktop.login1.Manager */

#define META_DBUS_TYPE_LOGIN1_MANAGER (meta_dbus_login1_manager_get_type ())
#define META_DBUS_LOGIN1_MANAGER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), META_DBUS_TYPE_LOGIN1_MANAGER, MetaDBusLogin1Manager))
#define META_DBUS_IS_LOGIN1_MANAGER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), META_DBUS_TYPE_LOGIN1_MANAGER))
#define META_DBUS_LOGIN1_MANAGER_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), META_DBUS_TYPE_LOGIN1_MANAGER, MetaDBusLogin1ManagerIface))

struct _MetaDBusLogin1Manager;
typedef struct _MetaDBusLogin1Manager MetaDBusLogin1Manager;
typedef struct _MetaDBusLogin1ManagerIface MetaDBusLogin1ManagerIface;

struct _MetaDBusLogin1ManagerIface
{
  GTypeInterface parent_iface;



  gboolean (*handle_activate_session) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_session_id);

  gboolean (*handle_activate_session_on_seat) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_session_id,
    const gchar *arg_seat_id);

  gboolean (*handle_attach_device) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_seat_id,
    const gchar *arg_sysfs_path,
    gboolean arg_interactive);

  gboolean (*handle_can_halt) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_can_hibernate) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_can_hybrid_sleep) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_can_power_off) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_can_reboot) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_can_reboot_parameter) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_can_reboot_to_boot_loader_entry) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_can_reboot_to_boot_loader_menu) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_can_reboot_to_firmware_setup) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_can_sleep) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_can_suspend) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_can_suspend_then_hibernate) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_cancel_scheduled_shutdown) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_create_session) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    guint arg_uid,
    guint arg_pid,
    const gchar *arg_service,
    const gchar *arg_type,
    const gchar *arg_class,
    const gchar *arg_desktop,
    const gchar *arg_seat_id,
    guint arg_vtnr,
    const gchar *arg_tty,
    const gchar *arg_display,
    gboolean arg_remote,
    const gchar *arg_remote_user,
    const gchar *arg_remote_host,
    GVariant *arg_properties);

  gboolean (*handle_create_session_with_pidfd) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    guint arg_uid,
    GVariant *arg_pidfd,
    const gchar *arg_service,
    const gchar *arg_type,
    const gchar *arg_class,
    const gchar *arg_desktop,
    const gchar *arg_seat_id,
    guint arg_vtnr,
    const gchar *arg_tty,
    const gchar *arg_display,
    gboolean arg_remote,
    const gchar *arg_remote_user,
    const gchar *arg_remote_host,
    guint64 arg_flags,
    GVariant *arg_properties);

  gboolean (*handle_flush_devices) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_interactive);

  gboolean (*handle_get_seat) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_seat_id);

  gboolean (*handle_get_session) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_session_id);

  gboolean (*handle_get_session_by_pid) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    guint arg_pid);

  gboolean (*handle_get_user) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    guint arg_uid);

  gboolean (*handle_get_user_by_pid) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    guint arg_pid);

  gboolean (*handle_halt) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_interactive);

  gboolean (*handle_halt_with_flags) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    guint64 arg_flags);

  gboolean (*handle_hibernate) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_interactive);

  gboolean (*handle_hibernate_with_flags) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    guint64 arg_flags);

  gboolean (*handle_hybrid_sleep) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_interactive);

  gboolean (*handle_hybrid_sleep_with_flags) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    guint64 arg_flags);

  gboolean (*handle_inhibit) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_what,
    const gchar *arg_who,
    const gchar *arg_why,
    const gchar *arg_mode);

  gboolean (*handle_kill_session) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_session_id,
    const gchar *arg_who,
    gint arg_signal_number);

  gboolean (*handle_kill_user) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    guint arg_uid,
    gint arg_signal_number);

  gboolean (*handle_list_inhibitors) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_list_seats) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_list_sessions) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_list_sessions_ex) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_list_users) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_lock_session) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_session_id);

  gboolean (*handle_lock_sessions) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_power_off) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_interactive);

  gboolean (*handle_power_off_with_flags) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    guint64 arg_flags);

  gboolean (*handle_reboot) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_interactive);

  gboolean (*handle_reboot_with_flags) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    guint64 arg_flags);

  gboolean (*handle_release_session) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_session_id);

  gboolean (*handle_schedule_shutdown) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_type,
    guint64 arg_usec);

  gboolean (*handle_set_reboot_parameter) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_parameter);

  gboolean (*handle_set_reboot_to_boot_loader_entry) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_boot_loader_entry);

  gboolean (*handle_set_reboot_to_boot_loader_menu) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    guint64 arg_timeout);

  gboolean (*handle_set_reboot_to_firmware_setup) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_enable);

  gboolean (*handle_set_user_linger) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    guint arg_uid,
    gboolean arg_enable,
    gboolean arg_interactive);

  gboolean (*handle_set_wall_message) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_wall_message,
    gboolean arg_enable);

  gboolean (*handle_sleep) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    guint64 arg_flags);

  gboolean (*handle_suspend) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_interactive);

  gboolean (*handle_suspend_then_hibernate) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_interactive);

  gboolean (*handle_suspend_then_hibernate_with_flags) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    guint64 arg_flags);

  gboolean (*handle_suspend_with_flags) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    guint64 arg_flags);

  gboolean (*handle_terminate_seat) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_seat_id);

  gboolean (*handle_terminate_session) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_session_id);

  gboolean (*handle_terminate_user) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    guint arg_uid);

  gboolean (*handle_unlock_session) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_session_id);

  gboolean (*handle_unlock_sessions) (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

  const gchar * (*get_block_inhibited) (MetaDBusLogin1Manager *object);

  const gchar *const * (*get_boot_loader_entries) (MetaDBusLogin1Manager *object);

  const gchar * (*get_delay_inhibited) (MetaDBusLogin1Manager *object);

  gboolean  (*get_docked) (MetaDBusLogin1Manager *object);

  gboolean  (*get_enable_wall_messages) (MetaDBusLogin1Manager *object);

  const gchar * (*get_handle_hibernate_key) (MetaDBusLogin1Manager *object);

  const gchar * (*get_handle_hibernate_key_long_press) (MetaDBusLogin1Manager *object);

  const gchar * (*get_handle_lid_switch) (MetaDBusLogin1Manager *object);

  const gchar * (*get_handle_lid_switch_docked) (MetaDBusLogin1Manager *object);

  const gchar * (*get_handle_lid_switch_external_power) (MetaDBusLogin1Manager *object);

  const gchar * (*get_handle_power_key) (MetaDBusLogin1Manager *object);

  const gchar * (*get_handle_power_key_long_press) (MetaDBusLogin1Manager *object);

  const gchar * (*get_handle_reboot_key) (MetaDBusLogin1Manager *object);

  const gchar * (*get_handle_reboot_key_long_press) (MetaDBusLogin1Manager *object);

  const gchar * (*get_handle_suspend_key) (MetaDBusLogin1Manager *object);

  const gchar * (*get_handle_suspend_key_long_press) (MetaDBusLogin1Manager *object);

  guint64  (*get_holdoff_timeout_usec) (MetaDBusLogin1Manager *object);

  const gchar * (*get_idle_action) (MetaDBusLogin1Manager *object);

  guint64  (*get_idle_action_usec) (MetaDBusLogin1Manager *object);

  gboolean  (*get_idle_hint) (MetaDBusLogin1Manager *object);

  guint64  (*get_idle_since_hint) (MetaDBusLogin1Manager *object);

  guint64  (*get_idle_since_hint_monotonic) (MetaDBusLogin1Manager *object);

  guint64  (*get_inhibit_delay_max_usec) (MetaDBusLogin1Manager *object);

  guint64  (*get_inhibitors_max) (MetaDBusLogin1Manager *object);

  const gchar *const * (*get_kill_exclude_users) (MetaDBusLogin1Manager *object);

  const gchar *const * (*get_kill_only_users) (MetaDBusLogin1Manager *object);

  gboolean  (*get_kill_user_processes) (MetaDBusLogin1Manager *object);

  gboolean  (*get_lid_closed) (MetaDBusLogin1Manager *object);

  guint  (*get_nauto_vts) (MetaDBusLogin1Manager *object);

  guint64  (*get_ncurrent_inhibitors) (MetaDBusLogin1Manager *object);

  guint64  (*get_ncurrent_sessions) (MetaDBusLogin1Manager *object);

  gboolean  (*get_on_external_power) (MetaDBusLogin1Manager *object);

  gboolean  (*get_preparing_for_shutdown) (MetaDBusLogin1Manager *object);

  gboolean  (*get_preparing_for_sleep) (MetaDBusLogin1Manager *object);

  const gchar * (*get_reboot_parameter) (MetaDBusLogin1Manager *object);

  const gchar * (*get_reboot_to_boot_loader_entry) (MetaDBusLogin1Manager *object);

  guint64  (*get_reboot_to_boot_loader_menu) (MetaDBusLogin1Manager *object);

  gboolean  (*get_reboot_to_firmware_setup) (MetaDBusLogin1Manager *object);

  gboolean  (*get_remove_ipc) (MetaDBusLogin1Manager *object);

  guint64  (*get_runtime_directory_inodes_max) (MetaDBusLogin1Manager *object);

  guint64  (*get_runtime_directory_size) (MetaDBusLogin1Manager *object);

  GVariant * (*get_scheduled_shutdown) (MetaDBusLogin1Manager *object);

  guint64  (*get_sessions_max) (MetaDBusLogin1Manager *object);

  const gchar *const * (*get_sleep_operation) (MetaDBusLogin1Manager *object);

  guint64  (*get_stop_idle_session_usec) (MetaDBusLogin1Manager *object);

  guint64  (*get_user_stop_delay_usec) (MetaDBusLogin1Manager *object);

  const gchar * (*get_wall_message) (MetaDBusLogin1Manager *object);

  void (*prepare_for_shutdown) (
    MetaDBusLogin1Manager *object,
    gboolean arg_start);

  void (*prepare_for_shutdown_with_metadata) (
    MetaDBusLogin1Manager *object,
    gboolean arg_start,
    GVariant *arg_metadata);

  void (*prepare_for_sleep) (
    MetaDBusLogin1Manager *object,
    gboolean arg_start);

  void (*seat_new) (
    MetaDBusLogin1Manager *object,
    const gchar *arg_seat_id,
    const gchar *arg_object_path);

  void (*seat_removed) (
    MetaDBusLogin1Manager *object,
    const gchar *arg_seat_id,
    const gchar *arg_object_path);

  void (*session_new) (
    MetaDBusLogin1Manager *object,
    const gchar *arg_session_id,
    const gchar *arg_object_path);

  void (*session_removed) (
    MetaDBusLogin1Manager *object,
    const gchar *arg_session_id,
    const gchar *arg_object_path);

  void (*user_new) (
    MetaDBusLogin1Manager *object,
    guint arg_uid,
    const gchar *arg_object_path);

  void (*user_removed) (
    MetaDBusLogin1Manager *object,
    guint arg_uid,
    const gchar *arg_object_path);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MetaDBusLogin1Manager, g_object_unref)
#endif

GType meta_dbus_login1_manager_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *meta_dbus_login1_manager_interface_info (void);
guint meta_dbus_login1_manager_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void meta_dbus_login1_manager_complete_get_session (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *object_path);

void meta_dbus_login1_manager_complete_get_session_by_pid (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *object_path);

void meta_dbus_login1_manager_complete_get_user (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *object_path);

void meta_dbus_login1_manager_complete_get_user_by_pid (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *object_path);

void meta_dbus_login1_manager_complete_get_seat (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *object_path);

void meta_dbus_login1_manager_complete_list_sessions (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    GVariant *sessions);

void meta_dbus_login1_manager_complete_list_sessions_ex (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    GVariant *sessions);

void meta_dbus_login1_manager_complete_list_users (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    GVariant *users);

void meta_dbus_login1_manager_complete_list_seats (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    GVariant *seats);

void meta_dbus_login1_manager_complete_list_inhibitors (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    GVariant *inhibitors);

void meta_dbus_login1_manager_complete_create_session (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *session_id,
    const gchar *object_path,
    const gchar *runtime_path,
    GVariant *fifo_fd,
    guint uid,
    const gchar *seat_id,
    guint vtnr,
    gboolean existing);

void meta_dbus_login1_manager_complete_create_session_with_pidfd (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *session_id,
    const gchar *object_path,
    const gchar *runtime_path,
    GVariant *fifo_fd,
    guint uid,
    const gchar *seat_id,
    guint vtnr,
    gboolean existing);

void meta_dbus_login1_manager_complete_release_session (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_activate_session (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_activate_session_on_seat (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_lock_session (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_unlock_session (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_lock_sessions (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_unlock_sessions (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_kill_session (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_kill_user (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_terminate_session (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_terminate_user (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_terminate_seat (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_set_user_linger (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_attach_device (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_flush_devices (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_power_off (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_power_off_with_flags (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_reboot (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_reboot_with_flags (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_halt (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_halt_with_flags (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_suspend (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_suspend_with_flags (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_hibernate (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_hibernate_with_flags (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_hybrid_sleep (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_hybrid_sleep_with_flags (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_suspend_then_hibernate (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_suspend_then_hibernate_with_flags (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_sleep (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_can_power_off (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *result);

void meta_dbus_login1_manager_complete_can_reboot (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *result);

void meta_dbus_login1_manager_complete_can_halt (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *result);

void meta_dbus_login1_manager_complete_can_suspend (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *result);

void meta_dbus_login1_manager_complete_can_hibernate (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *result);

void meta_dbus_login1_manager_complete_can_hybrid_sleep (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *result);

void meta_dbus_login1_manager_complete_can_suspend_then_hibernate (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *result);

void meta_dbus_login1_manager_complete_can_sleep (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *result);

void meta_dbus_login1_manager_complete_schedule_shutdown (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_cancel_scheduled_shutdown (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    gboolean cancelled);

void meta_dbus_login1_manager_complete_inhibit (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    GVariant *pipe_fd);

void meta_dbus_login1_manager_complete_can_reboot_parameter (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *result);

void meta_dbus_login1_manager_complete_set_reboot_parameter (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_can_reboot_to_firmware_setup (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *result);

void meta_dbus_login1_manager_complete_set_reboot_to_firmware_setup (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_can_reboot_to_boot_loader_menu (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *result);

void meta_dbus_login1_manager_complete_set_reboot_to_boot_loader_menu (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_can_reboot_to_boot_loader_entry (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation,
    const gchar *result);

void meta_dbus_login1_manager_complete_set_reboot_to_boot_loader_entry (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_manager_complete_set_wall_message (
    MetaDBusLogin1Manager *object,
    GDBusMethodInvocation *invocation);



/* D-Bus signal emissions functions: */
void meta_dbus_login1_manager_emit_session_new (
    MetaDBusLogin1Manager *object,
    const gchar *arg_session_id,
    const gchar *arg_object_path);

void meta_dbus_login1_manager_emit_session_removed (
    MetaDBusLogin1Manager *object,
    const gchar *arg_session_id,
    const gchar *arg_object_path);

void meta_dbus_login1_manager_emit_user_new (
    MetaDBusLogin1Manager *object,
    guint arg_uid,
    const gchar *arg_object_path);

void meta_dbus_login1_manager_emit_user_removed (
    MetaDBusLogin1Manager *object,
    guint arg_uid,
    const gchar *arg_object_path);

void meta_dbus_login1_manager_emit_seat_new (
    MetaDBusLogin1Manager *object,
    const gchar *arg_seat_id,
    const gchar *arg_object_path);

void meta_dbus_login1_manager_emit_seat_removed (
    MetaDBusLogin1Manager *object,
    const gchar *arg_seat_id,
    const gchar *arg_object_path);

void meta_dbus_login1_manager_emit_prepare_for_shutdown (
    MetaDBusLogin1Manager *object,
    gboolean arg_start);

void meta_dbus_login1_manager_emit_prepare_for_shutdown_with_metadata (
    MetaDBusLogin1Manager *object,
    gboolean arg_start,
    GVariant *arg_metadata);

void meta_dbus_login1_manager_emit_prepare_for_sleep (
    MetaDBusLogin1Manager *object,
    gboolean arg_start);



/* D-Bus method calls: */
void meta_dbus_login1_manager_call_get_session (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_session_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_get_session_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_object_path,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_get_session_sync (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_session_id,
    gchar ** out_object_path,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_get_session_by_pid (
    MetaDBusLogin1Manager *proxy,
    guint arg_pid,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_get_session_by_pid_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_object_path,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_get_session_by_pid_sync (
    MetaDBusLogin1Manager *proxy,
    guint arg_pid,
    gchar ** out_object_path,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_get_user (
    MetaDBusLogin1Manager *proxy,
    guint arg_uid,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_get_user_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_object_path,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_get_user_sync (
    MetaDBusLogin1Manager *proxy,
    guint arg_uid,
    gchar ** out_object_path,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_get_user_by_pid (
    MetaDBusLogin1Manager *proxy,
    guint arg_pid,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_get_user_by_pid_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_object_path,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_get_user_by_pid_sync (
    MetaDBusLogin1Manager *proxy,
    guint arg_pid,
    gchar ** out_object_path,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_get_seat (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_seat_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_get_seat_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_object_path,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_get_seat_sync (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_seat_id,
    gchar ** out_object_path,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_list_sessions (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_list_sessions_finish (
    MetaDBusLogin1Manager *proxy,
    GVariant ** out_sessions,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_list_sessions_sync (
    MetaDBusLogin1Manager *proxy,
    GVariant ** out_sessions,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_list_sessions_ex (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_list_sessions_ex_finish (
    MetaDBusLogin1Manager *proxy,
    GVariant ** out_sessions,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_list_sessions_ex_sync (
    MetaDBusLogin1Manager *proxy,
    GVariant ** out_sessions,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_list_users (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_list_users_finish (
    MetaDBusLogin1Manager *proxy,
    GVariant ** out_users,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_list_users_sync (
    MetaDBusLogin1Manager *proxy,
    GVariant ** out_users,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_list_seats (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_list_seats_finish (
    MetaDBusLogin1Manager *proxy,
    GVariant ** out_seats,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_list_seats_sync (
    MetaDBusLogin1Manager *proxy,
    GVariant ** out_seats,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_list_inhibitors (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_list_inhibitors_finish (
    MetaDBusLogin1Manager *proxy,
    GVariant ** out_inhibitors,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_list_inhibitors_sync (
    MetaDBusLogin1Manager *proxy,
    GVariant ** out_inhibitors,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_create_session (
    MetaDBusLogin1Manager *proxy,
    guint arg_uid,
    guint arg_pid,
    const gchar *arg_service,
    const gchar *arg_type,
    const gchar *arg_class,
    const gchar *arg_desktop,
    const gchar *arg_seat_id,
    guint arg_vtnr,
    const gchar *arg_tty,
    const gchar *arg_display,
    gboolean arg_remote,
    const gchar *arg_remote_user,
    const gchar *arg_remote_host,
    GVariant *arg_properties,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_create_session_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_session_id,
    gchar ** out_object_path,
    gchar ** out_runtime_path,
    GVariant ** out_fifo_fd,
    guint* out_uid,
    gchar ** out_seat_id,
    guint* out_vtnr,
    gboolean* out_existing,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_create_session_sync (
    MetaDBusLogin1Manager *proxy,
    guint arg_uid,
    guint arg_pid,
    const gchar *arg_service,
    const gchar *arg_type,
    const gchar *arg_class,
    const gchar *arg_desktop,
    const gchar *arg_seat_id,
    guint arg_vtnr,
    const gchar *arg_tty,
    const gchar *arg_display,
    gboolean arg_remote,
    const gchar *arg_remote_user,
    const gchar *arg_remote_host,
    GVariant *arg_properties,
    gchar ** out_session_id,
    gchar ** out_object_path,
    gchar ** out_runtime_path,
    GVariant ** out_fifo_fd,
    guint* out_uid,
    gchar ** out_seat_id,
    guint* out_vtnr,
    gboolean* out_existing,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_create_session_with_pidfd (
    MetaDBusLogin1Manager *proxy,
    guint arg_uid,
    GVariant *arg_pidfd,
    const gchar *arg_service,
    const gchar *arg_type,
    const gchar *arg_class,
    const gchar *arg_desktop,
    const gchar *arg_seat_id,
    guint arg_vtnr,
    const gchar *arg_tty,
    const gchar *arg_display,
    gboolean arg_remote,
    const gchar *arg_remote_user,
    const gchar *arg_remote_host,
    guint64 arg_flags,
    GVariant *arg_properties,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_create_session_with_pidfd_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_session_id,
    gchar ** out_object_path,
    gchar ** out_runtime_path,
    GVariant ** out_fifo_fd,
    guint* out_uid,
    gchar ** out_seat_id,
    guint* out_vtnr,
    gboolean* out_existing,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_create_session_with_pidfd_sync (
    MetaDBusLogin1Manager *proxy,
    guint arg_uid,
    GVariant *arg_pidfd,
    const gchar *arg_service,
    const gchar *arg_type,
    const gchar *arg_class,
    const gchar *arg_desktop,
    const gchar *arg_seat_id,
    guint arg_vtnr,
    const gchar *arg_tty,
    const gchar *arg_display,
    gboolean arg_remote,
    const gchar *arg_remote_user,
    const gchar *arg_remote_host,
    guint64 arg_flags,
    GVariant *arg_properties,
    gchar ** out_session_id,
    gchar ** out_object_path,
    gchar ** out_runtime_path,
    GVariant ** out_fifo_fd,
    guint* out_uid,
    gchar ** out_seat_id,
    guint* out_vtnr,
    gboolean* out_existing,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_release_session (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_session_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_release_session_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_release_session_sync (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_session_id,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_activate_session (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_session_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_activate_session_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_activate_session_sync (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_session_id,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_activate_session_on_seat (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_session_id,
    const gchar *arg_seat_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_activate_session_on_seat_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_activate_session_on_seat_sync (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_session_id,
    const gchar *arg_seat_id,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_lock_session (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_session_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_lock_session_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_lock_session_sync (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_session_id,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_unlock_session (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_session_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_unlock_session_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_unlock_session_sync (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_session_id,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_lock_sessions (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_lock_sessions_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_lock_sessions_sync (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_unlock_sessions (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_unlock_sessions_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_unlock_sessions_sync (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_kill_session (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_session_id,
    const gchar *arg_who,
    gint arg_signal_number,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_kill_session_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_kill_session_sync (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_session_id,
    const gchar *arg_who,
    gint arg_signal_number,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_kill_user (
    MetaDBusLogin1Manager *proxy,
    guint arg_uid,
    gint arg_signal_number,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_kill_user_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_kill_user_sync (
    MetaDBusLogin1Manager *proxy,
    guint arg_uid,
    gint arg_signal_number,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_terminate_session (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_session_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_terminate_session_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_terminate_session_sync (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_session_id,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_terminate_user (
    MetaDBusLogin1Manager *proxy,
    guint arg_uid,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_terminate_user_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_terminate_user_sync (
    MetaDBusLogin1Manager *proxy,
    guint arg_uid,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_terminate_seat (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_seat_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_terminate_seat_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_terminate_seat_sync (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_seat_id,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_set_user_linger (
    MetaDBusLogin1Manager *proxy,
    guint arg_uid,
    gboolean arg_enable,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_set_user_linger_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_set_user_linger_sync (
    MetaDBusLogin1Manager *proxy,
    guint arg_uid,
    gboolean arg_enable,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_attach_device (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_seat_id,
    const gchar *arg_sysfs_path,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_attach_device_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_attach_device_sync (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_seat_id,
    const gchar *arg_sysfs_path,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_flush_devices (
    MetaDBusLogin1Manager *proxy,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_flush_devices_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_flush_devices_sync (
    MetaDBusLogin1Manager *proxy,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_power_off (
    MetaDBusLogin1Manager *proxy,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_power_off_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_power_off_sync (
    MetaDBusLogin1Manager *proxy,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_power_off_with_flags (
    MetaDBusLogin1Manager *proxy,
    guint64 arg_flags,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_power_off_with_flags_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_power_off_with_flags_sync (
    MetaDBusLogin1Manager *proxy,
    guint64 arg_flags,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_reboot (
    MetaDBusLogin1Manager *proxy,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_reboot_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_reboot_sync (
    MetaDBusLogin1Manager *proxy,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_reboot_with_flags (
    MetaDBusLogin1Manager *proxy,
    guint64 arg_flags,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_reboot_with_flags_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_reboot_with_flags_sync (
    MetaDBusLogin1Manager *proxy,
    guint64 arg_flags,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_halt (
    MetaDBusLogin1Manager *proxy,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_halt_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_halt_sync (
    MetaDBusLogin1Manager *proxy,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_halt_with_flags (
    MetaDBusLogin1Manager *proxy,
    guint64 arg_flags,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_halt_with_flags_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_halt_with_flags_sync (
    MetaDBusLogin1Manager *proxy,
    guint64 arg_flags,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_suspend (
    MetaDBusLogin1Manager *proxy,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_suspend_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_suspend_sync (
    MetaDBusLogin1Manager *proxy,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_suspend_with_flags (
    MetaDBusLogin1Manager *proxy,
    guint64 arg_flags,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_suspend_with_flags_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_suspend_with_flags_sync (
    MetaDBusLogin1Manager *proxy,
    guint64 arg_flags,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_hibernate (
    MetaDBusLogin1Manager *proxy,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_hibernate_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_hibernate_sync (
    MetaDBusLogin1Manager *proxy,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_hibernate_with_flags (
    MetaDBusLogin1Manager *proxy,
    guint64 arg_flags,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_hibernate_with_flags_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_hibernate_with_flags_sync (
    MetaDBusLogin1Manager *proxy,
    guint64 arg_flags,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_hybrid_sleep (
    MetaDBusLogin1Manager *proxy,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_hybrid_sleep_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_hybrid_sleep_sync (
    MetaDBusLogin1Manager *proxy,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_hybrid_sleep_with_flags (
    MetaDBusLogin1Manager *proxy,
    guint64 arg_flags,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_hybrid_sleep_with_flags_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_hybrid_sleep_with_flags_sync (
    MetaDBusLogin1Manager *proxy,
    guint64 arg_flags,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_suspend_then_hibernate (
    MetaDBusLogin1Manager *proxy,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_suspend_then_hibernate_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_suspend_then_hibernate_sync (
    MetaDBusLogin1Manager *proxy,
    gboolean arg_interactive,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_suspend_then_hibernate_with_flags (
    MetaDBusLogin1Manager *proxy,
    guint64 arg_flags,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_suspend_then_hibernate_with_flags_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_suspend_then_hibernate_with_flags_sync (
    MetaDBusLogin1Manager *proxy,
    guint64 arg_flags,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_sleep (
    MetaDBusLogin1Manager *proxy,
    guint64 arg_flags,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_sleep_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_sleep_sync (
    MetaDBusLogin1Manager *proxy,
    guint64 arg_flags,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_can_power_off (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_can_power_off_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_can_power_off_sync (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_can_reboot (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_can_reboot_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_can_reboot_sync (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_can_halt (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_can_halt_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_can_halt_sync (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_can_suspend (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_can_suspend_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_can_suspend_sync (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_can_hibernate (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_can_hibernate_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_can_hibernate_sync (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_can_hybrid_sleep (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_can_hybrid_sleep_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_can_hybrid_sleep_sync (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_can_suspend_then_hibernate (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_can_suspend_then_hibernate_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_can_suspend_then_hibernate_sync (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_can_sleep (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_can_sleep_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_can_sleep_sync (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_schedule_shutdown (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_type,
    guint64 arg_usec,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_schedule_shutdown_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_schedule_shutdown_sync (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_type,
    guint64 arg_usec,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_cancel_scheduled_shutdown (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_cancel_scheduled_shutdown_finish (
    MetaDBusLogin1Manager *proxy,
    gboolean* out_cancelled,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_cancel_scheduled_shutdown_sync (
    MetaDBusLogin1Manager *proxy,
    gboolean* out_cancelled,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_inhibit (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_what,
    const gchar *arg_who,
    const gchar *arg_why,
    const gchar *arg_mode,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_inhibit_finish (
    MetaDBusLogin1Manager *proxy,
    GVariant ** out_pipe_fd,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_inhibit_sync (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_what,
    const gchar *arg_who,
    const gchar *arg_why,
    const gchar *arg_mode,
    GVariant ** out_pipe_fd,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_can_reboot_parameter (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_can_reboot_parameter_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_can_reboot_parameter_sync (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_set_reboot_parameter (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_parameter,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_set_reboot_parameter_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_set_reboot_parameter_sync (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_parameter,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_can_reboot_to_firmware_setup (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_can_reboot_to_firmware_setup_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_can_reboot_to_firmware_setup_sync (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_set_reboot_to_firmware_setup (
    MetaDBusLogin1Manager *proxy,
    gboolean arg_enable,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_set_reboot_to_firmware_setup_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_set_reboot_to_firmware_setup_sync (
    MetaDBusLogin1Manager *proxy,
    gboolean arg_enable,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_can_reboot_to_boot_loader_menu (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_can_reboot_to_boot_loader_menu_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_can_reboot_to_boot_loader_menu_sync (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_set_reboot_to_boot_loader_menu (
    MetaDBusLogin1Manager *proxy,
    guint64 arg_timeout,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_set_reboot_to_boot_loader_menu_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_set_reboot_to_boot_loader_menu_sync (
    MetaDBusLogin1Manager *proxy,
    guint64 arg_timeout,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_can_reboot_to_boot_loader_entry (
    MetaDBusLogin1Manager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_can_reboot_to_boot_loader_entry_finish (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_can_reboot_to_boot_loader_entry_sync (
    MetaDBusLogin1Manager *proxy,
    gchar ** out_result,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_set_reboot_to_boot_loader_entry (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_boot_loader_entry,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_set_reboot_to_boot_loader_entry_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_set_reboot_to_boot_loader_entry_sync (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_boot_loader_entry,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_manager_call_set_wall_message (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_wall_message,
    gboolean arg_enable,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_manager_call_set_wall_message_finish (
    MetaDBusLogin1Manager *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_manager_call_set_wall_message_sync (
    MetaDBusLogin1Manager *proxy,
    const gchar *arg_wall_message,
    gboolean arg_enable,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
gboolean meta_dbus_login1_manager_get_enable_wall_messages (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_enable_wall_messages (MetaDBusLogin1Manager *object, gboolean value);

const gchar *meta_dbus_login1_manager_get_wall_message (MetaDBusLogin1Manager *object);
gchar *meta_dbus_login1_manager_dup_wall_message (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_wall_message (MetaDBusLogin1Manager *object, const gchar *value);

guint meta_dbus_login1_manager_get_nauto_vts (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_nauto_vts (MetaDBusLogin1Manager *object, guint value);

const gchar *const *meta_dbus_login1_manager_get_kill_only_users (MetaDBusLogin1Manager *object);
gchar **meta_dbus_login1_manager_dup_kill_only_users (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_kill_only_users (MetaDBusLogin1Manager *object, const gchar *const *value);

const gchar *const *meta_dbus_login1_manager_get_kill_exclude_users (MetaDBusLogin1Manager *object);
gchar **meta_dbus_login1_manager_dup_kill_exclude_users (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_kill_exclude_users (MetaDBusLogin1Manager *object, const gchar *const *value);

gboolean meta_dbus_login1_manager_get_kill_user_processes (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_kill_user_processes (MetaDBusLogin1Manager *object, gboolean value);

const gchar *meta_dbus_login1_manager_get_reboot_parameter (MetaDBusLogin1Manager *object);
gchar *meta_dbus_login1_manager_dup_reboot_parameter (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_reboot_parameter (MetaDBusLogin1Manager *object, const gchar *value);

gboolean meta_dbus_login1_manager_get_reboot_to_firmware_setup (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_reboot_to_firmware_setup (MetaDBusLogin1Manager *object, gboolean value);

guint64 meta_dbus_login1_manager_get_reboot_to_boot_loader_menu (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_reboot_to_boot_loader_menu (MetaDBusLogin1Manager *object, guint64 value);

const gchar *meta_dbus_login1_manager_get_reboot_to_boot_loader_entry (MetaDBusLogin1Manager *object);
gchar *meta_dbus_login1_manager_dup_reboot_to_boot_loader_entry (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_reboot_to_boot_loader_entry (MetaDBusLogin1Manager *object, const gchar *value);

const gchar *const *meta_dbus_login1_manager_get_boot_loader_entries (MetaDBusLogin1Manager *object);
gchar **meta_dbus_login1_manager_dup_boot_loader_entries (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_boot_loader_entries (MetaDBusLogin1Manager *object, const gchar *const *value);

gboolean meta_dbus_login1_manager_get_idle_hint (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_idle_hint (MetaDBusLogin1Manager *object, gboolean value);

guint64 meta_dbus_login1_manager_get_idle_since_hint (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_idle_since_hint (MetaDBusLogin1Manager *object, guint64 value);

guint64 meta_dbus_login1_manager_get_idle_since_hint_monotonic (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_idle_since_hint_monotonic (MetaDBusLogin1Manager *object, guint64 value);

const gchar *meta_dbus_login1_manager_get_block_inhibited (MetaDBusLogin1Manager *object);
gchar *meta_dbus_login1_manager_dup_block_inhibited (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_block_inhibited (MetaDBusLogin1Manager *object, const gchar *value);

const gchar *meta_dbus_login1_manager_get_delay_inhibited (MetaDBusLogin1Manager *object);
gchar *meta_dbus_login1_manager_dup_delay_inhibited (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_delay_inhibited (MetaDBusLogin1Manager *object, const gchar *value);

guint64 meta_dbus_login1_manager_get_inhibit_delay_max_usec (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_inhibit_delay_max_usec (MetaDBusLogin1Manager *object, guint64 value);

guint64 meta_dbus_login1_manager_get_user_stop_delay_usec (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_user_stop_delay_usec (MetaDBusLogin1Manager *object, guint64 value);

const gchar *const *meta_dbus_login1_manager_get_sleep_operation (MetaDBusLogin1Manager *object);
gchar **meta_dbus_login1_manager_dup_sleep_operation (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_sleep_operation (MetaDBusLogin1Manager *object, const gchar *const *value);

const gchar *meta_dbus_login1_manager_get_handle_power_key (MetaDBusLogin1Manager *object);
gchar *meta_dbus_login1_manager_dup_handle_power_key (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_handle_power_key (MetaDBusLogin1Manager *object, const gchar *value);

const gchar *meta_dbus_login1_manager_get_handle_power_key_long_press (MetaDBusLogin1Manager *object);
gchar *meta_dbus_login1_manager_dup_handle_power_key_long_press (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_handle_power_key_long_press (MetaDBusLogin1Manager *object, const gchar *value);

const gchar *meta_dbus_login1_manager_get_handle_reboot_key (MetaDBusLogin1Manager *object);
gchar *meta_dbus_login1_manager_dup_handle_reboot_key (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_handle_reboot_key (MetaDBusLogin1Manager *object, const gchar *value);

const gchar *meta_dbus_login1_manager_get_handle_reboot_key_long_press (MetaDBusLogin1Manager *object);
gchar *meta_dbus_login1_manager_dup_handle_reboot_key_long_press (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_handle_reboot_key_long_press (MetaDBusLogin1Manager *object, const gchar *value);

const gchar *meta_dbus_login1_manager_get_handle_suspend_key (MetaDBusLogin1Manager *object);
gchar *meta_dbus_login1_manager_dup_handle_suspend_key (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_handle_suspend_key (MetaDBusLogin1Manager *object, const gchar *value);

const gchar *meta_dbus_login1_manager_get_handle_suspend_key_long_press (MetaDBusLogin1Manager *object);
gchar *meta_dbus_login1_manager_dup_handle_suspend_key_long_press (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_handle_suspend_key_long_press (MetaDBusLogin1Manager *object, const gchar *value);

const gchar *meta_dbus_login1_manager_get_handle_hibernate_key (MetaDBusLogin1Manager *object);
gchar *meta_dbus_login1_manager_dup_handle_hibernate_key (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_handle_hibernate_key (MetaDBusLogin1Manager *object, const gchar *value);

const gchar *meta_dbus_login1_manager_get_handle_hibernate_key_long_press (MetaDBusLogin1Manager *object);
gchar *meta_dbus_login1_manager_dup_handle_hibernate_key_long_press (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_handle_hibernate_key_long_press (MetaDBusLogin1Manager *object, const gchar *value);

const gchar *meta_dbus_login1_manager_get_handle_lid_switch (MetaDBusLogin1Manager *object);
gchar *meta_dbus_login1_manager_dup_handle_lid_switch (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_handle_lid_switch (MetaDBusLogin1Manager *object, const gchar *value);

const gchar *meta_dbus_login1_manager_get_handle_lid_switch_external_power (MetaDBusLogin1Manager *object);
gchar *meta_dbus_login1_manager_dup_handle_lid_switch_external_power (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_handle_lid_switch_external_power (MetaDBusLogin1Manager *object, const gchar *value);

const gchar *meta_dbus_login1_manager_get_handle_lid_switch_docked (MetaDBusLogin1Manager *object);
gchar *meta_dbus_login1_manager_dup_handle_lid_switch_docked (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_handle_lid_switch_docked (MetaDBusLogin1Manager *object, const gchar *value);

guint64 meta_dbus_login1_manager_get_holdoff_timeout_usec (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_holdoff_timeout_usec (MetaDBusLogin1Manager *object, guint64 value);

const gchar *meta_dbus_login1_manager_get_idle_action (MetaDBusLogin1Manager *object);
gchar *meta_dbus_login1_manager_dup_idle_action (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_idle_action (MetaDBusLogin1Manager *object, const gchar *value);

guint64 meta_dbus_login1_manager_get_idle_action_usec (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_idle_action_usec (MetaDBusLogin1Manager *object, guint64 value);

gboolean meta_dbus_login1_manager_get_preparing_for_shutdown (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_preparing_for_shutdown (MetaDBusLogin1Manager *object, gboolean value);

gboolean meta_dbus_login1_manager_get_preparing_for_sleep (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_preparing_for_sleep (MetaDBusLogin1Manager *object, gboolean value);

GVariant *meta_dbus_login1_manager_get_scheduled_shutdown (MetaDBusLogin1Manager *object);
GVariant *meta_dbus_login1_manager_dup_scheduled_shutdown (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_scheduled_shutdown (MetaDBusLogin1Manager *object, GVariant *value);

gboolean meta_dbus_login1_manager_get_docked (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_docked (MetaDBusLogin1Manager *object, gboolean value);

gboolean meta_dbus_login1_manager_get_lid_closed (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_lid_closed (MetaDBusLogin1Manager *object, gboolean value);

gboolean meta_dbus_login1_manager_get_on_external_power (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_on_external_power (MetaDBusLogin1Manager *object, gboolean value);

gboolean meta_dbus_login1_manager_get_remove_ipc (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_remove_ipc (MetaDBusLogin1Manager *object, gboolean value);

guint64 meta_dbus_login1_manager_get_runtime_directory_size (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_runtime_directory_size (MetaDBusLogin1Manager *object, guint64 value);

guint64 meta_dbus_login1_manager_get_runtime_directory_inodes_max (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_runtime_directory_inodes_max (MetaDBusLogin1Manager *object, guint64 value);

guint64 meta_dbus_login1_manager_get_inhibitors_max (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_inhibitors_max (MetaDBusLogin1Manager *object, guint64 value);

guint64 meta_dbus_login1_manager_get_ncurrent_inhibitors (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_ncurrent_inhibitors (MetaDBusLogin1Manager *object, guint64 value);

guint64 meta_dbus_login1_manager_get_sessions_max (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_sessions_max (MetaDBusLogin1Manager *object, guint64 value);

guint64 meta_dbus_login1_manager_get_ncurrent_sessions (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_ncurrent_sessions (MetaDBusLogin1Manager *object, guint64 value);

guint64 meta_dbus_login1_manager_get_stop_idle_session_usec (MetaDBusLogin1Manager *object);
void meta_dbus_login1_manager_set_stop_idle_session_usec (MetaDBusLogin1Manager *object, guint64 value);


/* ---- */

#define META_DBUS_TYPE_LOGIN1_MANAGER_PROXY (meta_dbus_login1_manager_proxy_get_type ())
#define META_DBUS_LOGIN1_MANAGER_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), META_DBUS_TYPE_LOGIN1_MANAGER_PROXY, MetaDBusLogin1ManagerProxy))
#define META_DBUS_LOGIN1_MANAGER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), META_DBUS_TYPE_LOGIN1_MANAGER_PROXY, MetaDBusLogin1ManagerProxyClass))
#define META_DBUS_LOGIN1_MANAGER_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), META_DBUS_TYPE_LOGIN1_MANAGER_PROXY, MetaDBusLogin1ManagerProxyClass))
#define META_DBUS_IS_LOGIN1_MANAGER_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), META_DBUS_TYPE_LOGIN1_MANAGER_PROXY))
#define META_DBUS_IS_LOGIN1_MANAGER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), META_DBUS_TYPE_LOGIN1_MANAGER_PROXY))

typedef struct _MetaDBusLogin1ManagerProxy MetaDBusLogin1ManagerProxy;
typedef struct _MetaDBusLogin1ManagerProxyClass MetaDBusLogin1ManagerProxyClass;
typedef struct _MetaDBusLogin1ManagerProxyPrivate MetaDBusLogin1ManagerProxyPrivate;

struct _MetaDBusLogin1ManagerProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  MetaDBusLogin1ManagerProxyPrivate *priv;
};

struct _MetaDBusLogin1ManagerProxyClass
{
  GDBusProxyClass parent_class;
};

GType meta_dbus_login1_manager_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MetaDBusLogin1ManagerProxy, g_object_unref)
#endif

void meta_dbus_login1_manager_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
MetaDBusLogin1Manager *meta_dbus_login1_manager_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
MetaDBusLogin1Manager *meta_dbus_login1_manager_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void meta_dbus_login1_manager_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
MetaDBusLogin1Manager *meta_dbus_login1_manager_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
MetaDBusLogin1Manager *meta_dbus_login1_manager_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define META_DBUS_TYPE_LOGIN1_MANAGER_SKELETON (meta_dbus_login1_manager_skeleton_get_type ())
#define META_DBUS_LOGIN1_MANAGER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), META_DBUS_TYPE_LOGIN1_MANAGER_SKELETON, MetaDBusLogin1ManagerSkeleton))
#define META_DBUS_LOGIN1_MANAGER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), META_DBUS_TYPE_LOGIN1_MANAGER_SKELETON, MetaDBusLogin1ManagerSkeletonClass))
#define META_DBUS_LOGIN1_MANAGER_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), META_DBUS_TYPE_LOGIN1_MANAGER_SKELETON, MetaDBusLogin1ManagerSkeletonClass))
#define META_DBUS_IS_LOGIN1_MANAGER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), META_DBUS_TYPE_LOGIN1_MANAGER_SKELETON))
#define META_DBUS_IS_LOGIN1_MANAGER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), META_DBUS_TYPE_LOGIN1_MANAGER_SKELETON))

typedef struct _MetaDBusLogin1ManagerSkeleton MetaDBusLogin1ManagerSkeleton;
typedef struct _MetaDBusLogin1ManagerSkeletonClass MetaDBusLogin1ManagerSkeletonClass;
typedef struct _MetaDBusLogin1ManagerSkeletonPrivate MetaDBusLogin1ManagerSkeletonPrivate;

struct _MetaDBusLogin1ManagerSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  MetaDBusLogin1ManagerSkeletonPrivate *priv;
};

struct _MetaDBusLogin1ManagerSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType meta_dbus_login1_manager_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MetaDBusLogin1ManagerSkeleton, g_object_unref)
#endif

MetaDBusLogin1Manager *meta_dbus_login1_manager_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.freedesktop.login1.Session */

#define META_DBUS_TYPE_LOGIN1_SESSION (meta_dbus_login1_session_get_type ())
#define META_DBUS_LOGIN1_SESSION(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), META_DBUS_TYPE_LOGIN1_SESSION, MetaDBusLogin1Session))
#define META_DBUS_IS_LOGIN1_SESSION(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), META_DBUS_TYPE_LOGIN1_SESSION))
#define META_DBUS_LOGIN1_SESSION_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), META_DBUS_TYPE_LOGIN1_SESSION, MetaDBusLogin1SessionIface))

struct _MetaDBusLogin1Session;
typedef struct _MetaDBusLogin1Session MetaDBusLogin1Session;
typedef struct _MetaDBusLogin1SessionIface MetaDBusLogin1SessionIface;

struct _MetaDBusLogin1SessionIface
{
  GTypeInterface parent_iface;



  gboolean (*handle_activate) (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_kill) (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_who,
    gint arg_signal_number);

  gboolean (*handle_lock) (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_pause_device_complete) (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation,
    guint arg_major,
    guint arg_minor);

  gboolean (*handle_release_control) (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_release_device) (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation,
    guint arg_major,
    guint arg_minor);

  gboolean (*handle_set_brightness) (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_subsystem,
    const gchar *arg_name,
    guint arg_brightness);

  gboolean (*handle_set_display) (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_display);

  gboolean (*handle_set_idle_hint) (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_idle);

  gboolean (*handle_set_locked_hint) (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_locked);

  gboolean (*handle_set_tty) (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation,
    GVariant *arg_tty_fd);

  gboolean (*handle_set_type) (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_type);

  gboolean (*handle_take_control) (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_force);

  gboolean (*handle_take_device) (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation,
    GUnixFDList *fd_list,
    guint arg_major,
    guint arg_minor);

  gboolean (*handle_terminate) (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_unlock) (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

  gboolean  (*get_active) (MetaDBusLogin1Session *object);

  guint  (*get_audit) (MetaDBusLogin1Session *object);

  const gchar * (*get_class) (MetaDBusLogin1Session *object);

  const gchar * (*get_desktop) (MetaDBusLogin1Session *object);

  const gchar * (*get_display) (MetaDBusLogin1Session *object);

  const gchar * (*get_id) (MetaDBusLogin1Session *object);

  gboolean  (*get_idle_hint) (MetaDBusLogin1Session *object);

  guint64  (*get_idle_since_hint) (MetaDBusLogin1Session *object);

  guint64  (*get_idle_since_hint_monotonic) (MetaDBusLogin1Session *object);

  guint  (*get_leader) (MetaDBusLogin1Session *object);

  gboolean  (*get_locked_hint) (MetaDBusLogin1Session *object);

  const gchar * (*get_name) (MetaDBusLogin1Session *object);

  gboolean  (*get_remote) (MetaDBusLogin1Session *object);

  const gchar * (*get_remote_host) (MetaDBusLogin1Session *object);

  const gchar * (*get_remote_user) (MetaDBusLogin1Session *object);

  const gchar * (*get_scope) (MetaDBusLogin1Session *object);

  GVariant * (*get_seat) (MetaDBusLogin1Session *object);

  const gchar * (*get_service) (MetaDBusLogin1Session *object);

  const gchar * (*get_state) (MetaDBusLogin1Session *object);

  guint64  (*get_timestamp) (MetaDBusLogin1Session *object);

  guint64  (*get_timestamp_monotonic) (MetaDBusLogin1Session *object);

  const gchar * (*get_tty) (MetaDBusLogin1Session *object);

  const gchar * (*get_type_) (MetaDBusLogin1Session *object);

  GVariant * (*get_user) (MetaDBusLogin1Session *object);

  guint  (*get_vtnr) (MetaDBusLogin1Session *object);

  void (*lock) (
    MetaDBusLogin1Session *object);

  void (*pause_device) (
    MetaDBusLogin1Session *object,
    guint arg_major,
    guint arg_minor,
    const gchar *arg_type);

  void (*resume_device) (
    MetaDBusLogin1Session *object,
    guint arg_major,
    guint arg_minor,
    GVariant *arg_fd);

  void (*unlock) (
    MetaDBusLogin1Session *object);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MetaDBusLogin1Session, g_object_unref)
#endif

GType meta_dbus_login1_session_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *meta_dbus_login1_session_interface_info (void);
guint meta_dbus_login1_session_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void meta_dbus_login1_session_complete_terminate (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_session_complete_activate (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_session_complete_lock (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_session_complete_unlock (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_session_complete_set_idle_hint (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_session_complete_set_locked_hint (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_session_complete_kill (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_session_complete_take_control (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_session_complete_release_control (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_session_complete_set_type (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_session_complete_set_display (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_session_complete_set_tty (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_session_complete_take_device (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation,
    GUnixFDList *fd_list,
    GVariant *fd,
    gboolean inactive);

void meta_dbus_login1_session_complete_release_device (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_session_complete_pause_device_complete (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_session_complete_set_brightness (
    MetaDBusLogin1Session *object,
    GDBusMethodInvocation *invocation);



/* D-Bus signal emissions functions: */
void meta_dbus_login1_session_emit_pause_device (
    MetaDBusLogin1Session *object,
    guint arg_major,
    guint arg_minor,
    const gchar *arg_type);

void meta_dbus_login1_session_emit_resume_device (
    MetaDBusLogin1Session *object,
    guint arg_major,
    guint arg_minor,
    GVariant *arg_fd);

void meta_dbus_login1_session_emit_lock (
    MetaDBusLogin1Session *object);

void meta_dbus_login1_session_emit_unlock (
    MetaDBusLogin1Session *object);



/* D-Bus method calls: */
void meta_dbus_login1_session_call_terminate (
    MetaDBusLogin1Session *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_session_call_terminate_finish (
    MetaDBusLogin1Session *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_session_call_terminate_sync (
    MetaDBusLogin1Session *proxy,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_session_call_activate (
    MetaDBusLogin1Session *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_session_call_activate_finish (
    MetaDBusLogin1Session *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_session_call_activate_sync (
    MetaDBusLogin1Session *proxy,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_session_call_lock (
    MetaDBusLogin1Session *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_session_call_lock_finish (
    MetaDBusLogin1Session *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_session_call_lock_sync (
    MetaDBusLogin1Session *proxy,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_session_call_unlock (
    MetaDBusLogin1Session *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_session_call_unlock_finish (
    MetaDBusLogin1Session *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_session_call_unlock_sync (
    MetaDBusLogin1Session *proxy,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_session_call_set_idle_hint (
    MetaDBusLogin1Session *proxy,
    gboolean arg_idle,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_session_call_set_idle_hint_finish (
    MetaDBusLogin1Session *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_session_call_set_idle_hint_sync (
    MetaDBusLogin1Session *proxy,
    gboolean arg_idle,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_session_call_set_locked_hint (
    MetaDBusLogin1Session *proxy,
    gboolean arg_locked,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_session_call_set_locked_hint_finish (
    MetaDBusLogin1Session *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_session_call_set_locked_hint_sync (
    MetaDBusLogin1Session *proxy,
    gboolean arg_locked,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_session_call_kill (
    MetaDBusLogin1Session *proxy,
    const gchar *arg_who,
    gint arg_signal_number,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_session_call_kill_finish (
    MetaDBusLogin1Session *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_session_call_kill_sync (
    MetaDBusLogin1Session *proxy,
    const gchar *arg_who,
    gint arg_signal_number,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_session_call_take_control (
    MetaDBusLogin1Session *proxy,
    gboolean arg_force,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_session_call_take_control_finish (
    MetaDBusLogin1Session *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_session_call_take_control_sync (
    MetaDBusLogin1Session *proxy,
    gboolean arg_force,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_session_call_release_control (
    MetaDBusLogin1Session *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_session_call_release_control_finish (
    MetaDBusLogin1Session *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_session_call_release_control_sync (
    MetaDBusLogin1Session *proxy,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_session_call_set_type (
    MetaDBusLogin1Session *proxy,
    const gchar *arg_type,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_session_call_set_type_finish (
    MetaDBusLogin1Session *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_session_call_set_type_sync (
    MetaDBusLogin1Session *proxy,
    const gchar *arg_type,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_session_call_set_display (
    MetaDBusLogin1Session *proxy,
    const gchar *arg_display,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_session_call_set_display_finish (
    MetaDBusLogin1Session *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_session_call_set_display_sync (
    MetaDBusLogin1Session *proxy,
    const gchar *arg_display,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_session_call_set_tty (
    MetaDBusLogin1Session *proxy,
    GVariant *arg_tty_fd,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_session_call_set_tty_finish (
    MetaDBusLogin1Session *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_session_call_set_tty_sync (
    MetaDBusLogin1Session *proxy,
    GVariant *arg_tty_fd,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_session_call_take_device (
    MetaDBusLogin1Session *proxy,
    guint arg_major,
    guint arg_minor,
    GUnixFDList *fd_list,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_session_call_take_device_finish (
    MetaDBusLogin1Session *proxy,
    GVariant ** out_fd,
    gboolean* out_inactive,
    GUnixFDList **out_fd_list,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_session_call_take_device_sync (
    MetaDBusLogin1Session *proxy,
    guint arg_major,
    guint arg_minor,
    GUnixFDList  *fd_list,
    GVariant ** out_fd,
    gboolean* out_inactive,
    GUnixFDList **out_fd_list,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_session_call_release_device (
    MetaDBusLogin1Session *proxy,
    guint arg_major,
    guint arg_minor,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_session_call_release_device_finish (
    MetaDBusLogin1Session *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_session_call_release_device_sync (
    MetaDBusLogin1Session *proxy,
    guint arg_major,
    guint arg_minor,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_session_call_pause_device_complete (
    MetaDBusLogin1Session *proxy,
    guint arg_major,
    guint arg_minor,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_session_call_pause_device_complete_finish (
    MetaDBusLogin1Session *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_session_call_pause_device_complete_sync (
    MetaDBusLogin1Session *proxy,
    guint arg_major,
    guint arg_minor,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_session_call_set_brightness (
    MetaDBusLogin1Session *proxy,
    const gchar *arg_subsystem,
    const gchar *arg_name,
    guint arg_brightness,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_session_call_set_brightness_finish (
    MetaDBusLogin1Session *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_session_call_set_brightness_sync (
    MetaDBusLogin1Session *proxy,
    const gchar *arg_subsystem,
    const gchar *arg_name,
    guint arg_brightness,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
const gchar *meta_dbus_login1_session_get_id (MetaDBusLogin1Session *object);
gchar *meta_dbus_login1_session_dup_id (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_id (MetaDBusLogin1Session *object, const gchar *value);

GVariant *meta_dbus_login1_session_get_user (MetaDBusLogin1Session *object);
GVariant *meta_dbus_login1_session_dup_user (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_user (MetaDBusLogin1Session *object, GVariant *value);

const gchar *meta_dbus_login1_session_get_name (MetaDBusLogin1Session *object);
gchar *meta_dbus_login1_session_dup_name (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_name (MetaDBusLogin1Session *object, const gchar *value);

guint64 meta_dbus_login1_session_get_timestamp (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_timestamp (MetaDBusLogin1Session *object, guint64 value);

guint64 meta_dbus_login1_session_get_timestamp_monotonic (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_timestamp_monotonic (MetaDBusLogin1Session *object, guint64 value);

guint meta_dbus_login1_session_get_vtnr (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_vtnr (MetaDBusLogin1Session *object, guint value);

GVariant *meta_dbus_login1_session_get_seat (MetaDBusLogin1Session *object);
GVariant *meta_dbus_login1_session_dup_seat (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_seat (MetaDBusLogin1Session *object, GVariant *value);

const gchar *meta_dbus_login1_session_get_tty (MetaDBusLogin1Session *object);
gchar *meta_dbus_login1_session_dup_tty (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_tty (MetaDBusLogin1Session *object, const gchar *value);

const gchar *meta_dbus_login1_session_get_display (MetaDBusLogin1Session *object);
gchar *meta_dbus_login1_session_dup_display (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_display (MetaDBusLogin1Session *object, const gchar *value);

gboolean meta_dbus_login1_session_get_remote (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_remote (MetaDBusLogin1Session *object, gboolean value);

const gchar *meta_dbus_login1_session_get_remote_host (MetaDBusLogin1Session *object);
gchar *meta_dbus_login1_session_dup_remote_host (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_remote_host (MetaDBusLogin1Session *object, const gchar *value);

const gchar *meta_dbus_login1_session_get_remote_user (MetaDBusLogin1Session *object);
gchar *meta_dbus_login1_session_dup_remote_user (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_remote_user (MetaDBusLogin1Session *object, const gchar *value);

const gchar *meta_dbus_login1_session_get_service (MetaDBusLogin1Session *object);
gchar *meta_dbus_login1_session_dup_service (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_service (MetaDBusLogin1Session *object, const gchar *value);

const gchar *meta_dbus_login1_session_get_desktop (MetaDBusLogin1Session *object);
gchar *meta_dbus_login1_session_dup_desktop (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_desktop (MetaDBusLogin1Session *object, const gchar *value);

const gchar *meta_dbus_login1_session_get_scope (MetaDBusLogin1Session *object);
gchar *meta_dbus_login1_session_dup_scope (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_scope (MetaDBusLogin1Session *object, const gchar *value);

guint meta_dbus_login1_session_get_leader (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_leader (MetaDBusLogin1Session *object, guint value);

guint meta_dbus_login1_session_get_audit (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_audit (MetaDBusLogin1Session *object, guint value);

const gchar *meta_dbus_login1_session_get_type_ (MetaDBusLogin1Session *object);
gchar *meta_dbus_login1_session_dup_type_ (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_type_ (MetaDBusLogin1Session *object, const gchar *value);

const gchar *meta_dbus_login1_session_get_class (MetaDBusLogin1Session *object);
gchar *meta_dbus_login1_session_dup_class (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_class (MetaDBusLogin1Session *object, const gchar *value);

gboolean meta_dbus_login1_session_get_active (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_active (MetaDBusLogin1Session *object, gboolean value);

const gchar *meta_dbus_login1_session_get_state (MetaDBusLogin1Session *object);
gchar *meta_dbus_login1_session_dup_state (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_state (MetaDBusLogin1Session *object, const gchar *value);

gboolean meta_dbus_login1_session_get_idle_hint (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_idle_hint (MetaDBusLogin1Session *object, gboolean value);

guint64 meta_dbus_login1_session_get_idle_since_hint (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_idle_since_hint (MetaDBusLogin1Session *object, guint64 value);

guint64 meta_dbus_login1_session_get_idle_since_hint_monotonic (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_idle_since_hint_monotonic (MetaDBusLogin1Session *object, guint64 value);

gboolean meta_dbus_login1_session_get_locked_hint (MetaDBusLogin1Session *object);
void meta_dbus_login1_session_set_locked_hint (MetaDBusLogin1Session *object, gboolean value);


/* ---- */

#define META_DBUS_TYPE_LOGIN1_SESSION_PROXY (meta_dbus_login1_session_proxy_get_type ())
#define META_DBUS_LOGIN1_SESSION_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), META_DBUS_TYPE_LOGIN1_SESSION_PROXY, MetaDBusLogin1SessionProxy))
#define META_DBUS_LOGIN1_SESSION_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), META_DBUS_TYPE_LOGIN1_SESSION_PROXY, MetaDBusLogin1SessionProxyClass))
#define META_DBUS_LOGIN1_SESSION_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), META_DBUS_TYPE_LOGIN1_SESSION_PROXY, MetaDBusLogin1SessionProxyClass))
#define META_DBUS_IS_LOGIN1_SESSION_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), META_DBUS_TYPE_LOGIN1_SESSION_PROXY))
#define META_DBUS_IS_LOGIN1_SESSION_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), META_DBUS_TYPE_LOGIN1_SESSION_PROXY))

typedef struct _MetaDBusLogin1SessionProxy MetaDBusLogin1SessionProxy;
typedef struct _MetaDBusLogin1SessionProxyClass MetaDBusLogin1SessionProxyClass;
typedef struct _MetaDBusLogin1SessionProxyPrivate MetaDBusLogin1SessionProxyPrivate;

struct _MetaDBusLogin1SessionProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  MetaDBusLogin1SessionProxyPrivate *priv;
};

struct _MetaDBusLogin1SessionProxyClass
{
  GDBusProxyClass parent_class;
};

GType meta_dbus_login1_session_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MetaDBusLogin1SessionProxy, g_object_unref)
#endif

void meta_dbus_login1_session_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
MetaDBusLogin1Session *meta_dbus_login1_session_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
MetaDBusLogin1Session *meta_dbus_login1_session_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void meta_dbus_login1_session_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
MetaDBusLogin1Session *meta_dbus_login1_session_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
MetaDBusLogin1Session *meta_dbus_login1_session_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define META_DBUS_TYPE_LOGIN1_SESSION_SKELETON (meta_dbus_login1_session_skeleton_get_type ())
#define META_DBUS_LOGIN1_SESSION_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), META_DBUS_TYPE_LOGIN1_SESSION_SKELETON, MetaDBusLogin1SessionSkeleton))
#define META_DBUS_LOGIN1_SESSION_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), META_DBUS_TYPE_LOGIN1_SESSION_SKELETON, MetaDBusLogin1SessionSkeletonClass))
#define META_DBUS_LOGIN1_SESSION_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), META_DBUS_TYPE_LOGIN1_SESSION_SKELETON, MetaDBusLogin1SessionSkeletonClass))
#define META_DBUS_IS_LOGIN1_SESSION_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), META_DBUS_TYPE_LOGIN1_SESSION_SKELETON))
#define META_DBUS_IS_LOGIN1_SESSION_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), META_DBUS_TYPE_LOGIN1_SESSION_SKELETON))

typedef struct _MetaDBusLogin1SessionSkeleton MetaDBusLogin1SessionSkeleton;
typedef struct _MetaDBusLogin1SessionSkeletonClass MetaDBusLogin1SessionSkeletonClass;
typedef struct _MetaDBusLogin1SessionSkeletonPrivate MetaDBusLogin1SessionSkeletonPrivate;

struct _MetaDBusLogin1SessionSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  MetaDBusLogin1SessionSkeletonPrivate *priv;
};

struct _MetaDBusLogin1SessionSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType meta_dbus_login1_session_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MetaDBusLogin1SessionSkeleton, g_object_unref)
#endif

MetaDBusLogin1Session *meta_dbus_login1_session_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.freedesktop.login1.Seat */

#define META_DBUS_TYPE_LOGIN1_SEAT (meta_dbus_login1_seat_get_type ())
#define META_DBUS_LOGIN1_SEAT(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), META_DBUS_TYPE_LOGIN1_SEAT, MetaDBusLogin1Seat))
#define META_DBUS_IS_LOGIN1_SEAT(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), META_DBUS_TYPE_LOGIN1_SEAT))
#define META_DBUS_LOGIN1_SEAT_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), META_DBUS_TYPE_LOGIN1_SEAT, MetaDBusLogin1SeatIface))

struct _MetaDBusLogin1Seat;
typedef struct _MetaDBusLogin1Seat MetaDBusLogin1Seat;
typedef struct _MetaDBusLogin1SeatIface MetaDBusLogin1SeatIface;

struct _MetaDBusLogin1SeatIface
{
  GTypeInterface parent_iface;


  gboolean (*handle_activate_session) (
    MetaDBusLogin1Seat *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_session_id);

  gboolean (*handle_switch_to) (
    MetaDBusLogin1Seat *object,
    GDBusMethodInvocation *invocation,
    guint arg_vtnr);

  gboolean (*handle_switch_to_next) (
    MetaDBusLogin1Seat *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_switch_to_previous) (
    MetaDBusLogin1Seat *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_terminate) (
    MetaDBusLogin1Seat *object,
    GDBusMethodInvocation *invocation);

  GVariant * (*get_active_session) (MetaDBusLogin1Seat *object);

  gboolean  (*get_can_graphical) (MetaDBusLogin1Seat *object);

  gboolean  (*get_can_tty) (MetaDBusLogin1Seat *object);

  const gchar * (*get_id) (MetaDBusLogin1Seat *object);

  gboolean  (*get_idle_hint) (MetaDBusLogin1Seat *object);

  guint64  (*get_idle_since_hint) (MetaDBusLogin1Seat *object);

  guint64  (*get_idle_since_hint_monotonic) (MetaDBusLogin1Seat *object);

  GVariant * (*get_sessions) (MetaDBusLogin1Seat *object);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MetaDBusLogin1Seat, g_object_unref)
#endif

GType meta_dbus_login1_seat_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *meta_dbus_login1_seat_interface_info (void);
guint meta_dbus_login1_seat_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void meta_dbus_login1_seat_complete_terminate (
    MetaDBusLogin1Seat *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_seat_complete_activate_session (
    MetaDBusLogin1Seat *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_seat_complete_switch_to (
    MetaDBusLogin1Seat *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_seat_complete_switch_to_next (
    MetaDBusLogin1Seat *object,
    GDBusMethodInvocation *invocation);

void meta_dbus_login1_seat_complete_switch_to_previous (
    MetaDBusLogin1Seat *object,
    GDBusMethodInvocation *invocation);



/* D-Bus method calls: */
void meta_dbus_login1_seat_call_terminate (
    MetaDBusLogin1Seat *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_seat_call_terminate_finish (
    MetaDBusLogin1Seat *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_seat_call_terminate_sync (
    MetaDBusLogin1Seat *proxy,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_seat_call_activate_session (
    MetaDBusLogin1Seat *proxy,
    const gchar *arg_session_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_seat_call_activate_session_finish (
    MetaDBusLogin1Seat *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_seat_call_activate_session_sync (
    MetaDBusLogin1Seat *proxy,
    const gchar *arg_session_id,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_seat_call_switch_to (
    MetaDBusLogin1Seat *proxy,
    guint arg_vtnr,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_seat_call_switch_to_finish (
    MetaDBusLogin1Seat *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_seat_call_switch_to_sync (
    MetaDBusLogin1Seat *proxy,
    guint arg_vtnr,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_seat_call_switch_to_next (
    MetaDBusLogin1Seat *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_seat_call_switch_to_next_finish (
    MetaDBusLogin1Seat *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_seat_call_switch_to_next_sync (
    MetaDBusLogin1Seat *proxy,
    GCancellable *cancellable,
    GError **error);

void meta_dbus_login1_seat_call_switch_to_previous (
    MetaDBusLogin1Seat *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean meta_dbus_login1_seat_call_switch_to_previous_finish (
    MetaDBusLogin1Seat *proxy,
    GAsyncResult *res,
    GError **error);

gboolean meta_dbus_login1_seat_call_switch_to_previous_sync (
    MetaDBusLogin1Seat *proxy,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
const gchar *meta_dbus_login1_seat_get_id (MetaDBusLogin1Seat *object);
gchar *meta_dbus_login1_seat_dup_id (MetaDBusLogin1Seat *object);
void meta_dbus_login1_seat_set_id (MetaDBusLogin1Seat *object, const gchar *value);

GVariant *meta_dbus_login1_seat_get_active_session (MetaDBusLogin1Seat *object);
GVariant *meta_dbus_login1_seat_dup_active_session (MetaDBusLogin1Seat *object);
void meta_dbus_login1_seat_set_active_session (MetaDBusLogin1Seat *object, GVariant *value);

gboolean meta_dbus_login1_seat_get_can_tty (MetaDBusLogin1Seat *object);
void meta_dbus_login1_seat_set_can_tty (MetaDBusLogin1Seat *object, gboolean value);

gboolean meta_dbus_login1_seat_get_can_graphical (MetaDBusLogin1Seat *object);
void meta_dbus_login1_seat_set_can_graphical (MetaDBusLogin1Seat *object, gboolean value);

GVariant *meta_dbus_login1_seat_get_sessions (MetaDBusLogin1Seat *object);
GVariant *meta_dbus_login1_seat_dup_sessions (MetaDBusLogin1Seat *object);
void meta_dbus_login1_seat_set_sessions (MetaDBusLogin1Seat *object, GVariant *value);

gboolean meta_dbus_login1_seat_get_idle_hint (MetaDBusLogin1Seat *object);
void meta_dbus_login1_seat_set_idle_hint (MetaDBusLogin1Seat *object, gboolean value);

guint64 meta_dbus_login1_seat_get_idle_since_hint (MetaDBusLogin1Seat *object);
void meta_dbus_login1_seat_set_idle_since_hint (MetaDBusLogin1Seat *object, guint64 value);

guint64 meta_dbus_login1_seat_get_idle_since_hint_monotonic (MetaDBusLogin1Seat *object);
void meta_dbus_login1_seat_set_idle_since_hint_monotonic (MetaDBusLogin1Seat *object, guint64 value);


/* ---- */

#define META_DBUS_TYPE_LOGIN1_SEAT_PROXY (meta_dbus_login1_seat_proxy_get_type ())
#define META_DBUS_LOGIN1_SEAT_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), META_DBUS_TYPE_LOGIN1_SEAT_PROXY, MetaDBusLogin1SeatProxy))
#define META_DBUS_LOGIN1_SEAT_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), META_DBUS_TYPE_LOGIN1_SEAT_PROXY, MetaDBusLogin1SeatProxyClass))
#define META_DBUS_LOGIN1_SEAT_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), META_DBUS_TYPE_LOGIN1_SEAT_PROXY, MetaDBusLogin1SeatProxyClass))
#define META_DBUS_IS_LOGIN1_SEAT_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), META_DBUS_TYPE_LOGIN1_SEAT_PROXY))
#define META_DBUS_IS_LOGIN1_SEAT_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), META_DBUS_TYPE_LOGIN1_SEAT_PROXY))

typedef struct _MetaDBusLogin1SeatProxy MetaDBusLogin1SeatProxy;
typedef struct _MetaDBusLogin1SeatProxyClass MetaDBusLogin1SeatProxyClass;
typedef struct _MetaDBusLogin1SeatProxyPrivate MetaDBusLogin1SeatProxyPrivate;

struct _MetaDBusLogin1SeatProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  MetaDBusLogin1SeatProxyPrivate *priv;
};

struct _MetaDBusLogin1SeatProxyClass
{
  GDBusProxyClass parent_class;
};

GType meta_dbus_login1_seat_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MetaDBusLogin1SeatProxy, g_object_unref)
#endif

void meta_dbus_login1_seat_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
MetaDBusLogin1Seat *meta_dbus_login1_seat_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
MetaDBusLogin1Seat *meta_dbus_login1_seat_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void meta_dbus_login1_seat_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
MetaDBusLogin1Seat *meta_dbus_login1_seat_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
MetaDBusLogin1Seat *meta_dbus_login1_seat_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define META_DBUS_TYPE_LOGIN1_SEAT_SKELETON (meta_dbus_login1_seat_skeleton_get_type ())
#define META_DBUS_LOGIN1_SEAT_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), META_DBUS_TYPE_LOGIN1_SEAT_SKELETON, MetaDBusLogin1SeatSkeleton))
#define META_DBUS_LOGIN1_SEAT_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), META_DBUS_TYPE_LOGIN1_SEAT_SKELETON, MetaDBusLogin1SeatSkeletonClass))
#define META_DBUS_LOGIN1_SEAT_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), META_DBUS_TYPE_LOGIN1_SEAT_SKELETON, MetaDBusLogin1SeatSkeletonClass))
#define META_DBUS_IS_LOGIN1_SEAT_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), META_DBUS_TYPE_LOGIN1_SEAT_SKELETON))
#define META_DBUS_IS_LOGIN1_SEAT_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), META_DBUS_TYPE_LOGIN1_SEAT_SKELETON))

typedef struct _MetaDBusLogin1SeatSkeleton MetaDBusLogin1SeatSkeleton;
typedef struct _MetaDBusLogin1SeatSkeletonClass MetaDBusLogin1SeatSkeletonClass;
typedef struct _MetaDBusLogin1SeatSkeletonPrivate MetaDBusLogin1SeatSkeletonPrivate;

struct _MetaDBusLogin1SeatSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  MetaDBusLogin1SeatSkeletonPrivate *priv;
};

struct _MetaDBusLogin1SeatSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType meta_dbus_login1_seat_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MetaDBusLogin1SeatSkeleton, g_object_unref)
#endif

MetaDBusLogin1Seat *meta_dbus_login1_seat_skeleton_new (void);


G_END_DECLS

#endif /* __META_DBUS_LOGIN1_H__ */
